@@ -356,7 +356,7 @@ __DATA__
   },
   /* --------------------------------------------------------------------------------------------------------------------------------- */
   { L0_TERMINAL_RESTRICTED_ASCII_GRAPH_CHARACTERS, MARPAESLIF_TERMINAL_TYPE_REGEX, NULL,
-    "[!#$%&*+./;?\\[\\\\\\]^_`~A-Za-z0-9][!#$%&*+./;?\\[\\\\\\]^_`~A-Za-z0-9]*",
+    "[!#$%&*+./;?\\[\\\\\\]^_`~A-Za-z0-9]+",
     NULL, NULL
   },
   /* --------------------------------------------------------------------------------------------------------------------------------- */
