@@ -157,12 +157,14 @@ struct marpaESLIFSymbol {
   int                          priorityi;              /* Symbol priority */
   genericStack_t               _nullableRuleStack;     /* Used during validation, to determine nullable semantics */
   genericStack_t              *nullableRuleStackp;     /* Pointer to _nullableRuleStack */
-  marpaESLIFAction_t          *nullableActionp;        /* Nullable semantic */
+  marpaESLIFAction_t          *nullableActionp;        /* Nullable semantic, only for meta symbols that are not lexemes */
   int                          propertyBitSet;
   int                          eventBitSet;
   genericStack_t               _lhsRuleStack;          /* Stack of rules having this symbol as LHS */
   genericStack_t              *lhsRuleStackp;          /* Pointer to stack of rules having this symbol as LHS */
   marpaESLIF_symbol_t         *exceptionp;             /* Pointer to an exception itself, the one after the '-' character */
+  marpaESLIFAction_t          *symbolActionp;          /* Custom symbol, only for terminals or lexemes */
+  marpaESLIFAction_t          *ifActionp;              /* if semantic, only for meta symbols that are lexemes or terminals */
 };
 
 /* A rule */
@@ -486,7 +488,8 @@ marpaESLIFRecognizerOption_t marpaESLIFRecognizerOption_default_template = {
   0,                 /* trackb */
   MARPAESLIF_BUFSIZ, /* bufsizl */
   50,                /* buftriggerperci */
-  50                 /* bufaddperci */
+  50,                /* bufaddperci */
+  NULL               /* ifActionResolverp */
 };
 
 marpaESLIFValueOption_t marpaESLIFValueOption_default_template = {
